
local FOLDER_NAME, SSA = ...

local L = LibStub("AceLocale-3.0"):GetLocale("ShamanAuras", true)
local Auras = LibStub("AceAddon-3.0"):GetAddon("ShamanAuras")
local AceGUI = LibStub("AceGUI-3.0");

local lgIcon,lgGlow,smIcon,smGlow = 32,45,25,35;
--local lg,sm,gl = 32,25,45; -- Square Dimensions: Large, Small, Glow
local x,y = 0,0,0;
local bg,low,med,high = "BACKGROUND","LOW","MEDIUM","HIGH"

-------------------------------------------------------------------------------------------------------
----- Build and Initialize Frames & Frame Groups
-------------------------------------------------------------------------------------------------------

-- Aura Group Builder
local function CreateGroup(name,parent)
	SSA[name] = CreateFrame("Frame",name,parent);
	local Group = SSA[name];
	Group:SetFrameStrata(bg);
	--Group:RegisterForDrag("LeftButton");
	
	return Group;
end

-- Aura Icon Builder
local function InitializeFrames(name,parent,icon,iconSize,glowSize,charge)
	SSA[name] = CreateFrame("Frame",name,parent);
	local Frame = SSA[name];
	Frame:SetFrameStrata("LOW");
	Frame:SetWidth(iconSize);
	Frame:SetHeight(iconSize);

	Frame.texture = Frame:CreateTexture(nil,"BACKGROUND");
	Frame.texture:SetTexture("Interface\\addons\\ShamanAuras\\media\\ICONS\\"..icon);
	Frame.texture:SetAllPoints(Frame);

	Frame.CD = CreateFrame("Cooldown", name.."CD", Frame, "CooldownFrameTemplate");
	Frame.CD:SetAllPoints(Frame);
	
	Frame.CD.text = Frame.CD:CreateFontString(nil, "MEDIUM", "GameFontHighlightLarge");
	Frame.CD.text:SetAllPoints(Frame.CD);
	Frame.CD.text:SetPoint("CENTER",0,0);
	Frame.CD.text:SetTextColor(1,1,0,1);
	
	if (glowSize) then
		SSA[name.."Glow"] = CreateFrame("Frame",name.."Glow",Frame);
		local Glow = SSA[name.."Glow"];
		Glow:SetPoint("CENTER",0,0);
		Glow:SetFrameStrata("BACKGROUND");
		Glow:SetWidth(glowSize);
		Glow:SetHeight(glowSize);
		Glow:Show();
	end
	if (charge) then
		Frame.ChargeCD = CreateFrame("Cooldown", name.."ChargeCD", Frame, "CooldownFrameTemplate");
		Frame.ChargeCD:SetAllPoints(Frame);
		Frame.ChargeCD:SetFrameStrata("LOW");
		Frame.ChargeCD:Show()

		Frame.Charges = CreateFrame("Frame",name.."Charges",Frame);
		Frame.Charges:SetAllPoints(Frame);
		Frame.Charges:SetFrameStrata(med);
		Frame.Charges:SetWidth(iconSize);
		Frame.Charges:SetHeight(iconSize);

		Frame.Charges.text = Frame.Charges:CreateFontString(nil, "MEDIUM", "GameFontHighlightLarge");
		Frame.Charges.text:SetPoint("BOTTOMRIGHT",-3,3);
		Frame.Charges.text:SetFont("Interface\\addons\\ShamanAuras\\Media\\fonts\\ABF.ttf", 13.5,"OUTLINE");
		Frame.Charges.text:SetTextColor(1,1,1,1);		
	end
end


local AuraGroup,LargeIconGrpTop,LargeIconGrpBot,SmallIconGrpLeft,SmallIconGrpRight

-- Build Elemental Aura Group Containers
AuraGroup = CreateGroup("AuraGroupEle",UIParent);
LargeIconGrpTop = CreateGroup("LargeIconGrpTopEle",AuraGroup);
LargeIconGrpBot = CreateGroup("LargeIconGrpBotEle",AuraGroup);
SmallIconGrpLeft = CreateGroup("SmallIconGrpLeftEle",AuraGroup);
SmallIconGrpRight = CreateGroup("SmallIconGrpRightEle",AuraGroup);

-- Build Large Elemental Icon Frames
InitializeFrames("AscendanceEle",LargeIconGrpBot,"shared\\ascendance",lgIcon);
InitializeFrames("EarthShock",LargeIconGrpTop,"elemental\\earth_shock",lgIcon,lgGlow);
InitializeFrames("ElementalBlast",LargeIconGrpTop,"elemental\\elemental_blast",lgIcon);
InitializeFrames("ElementalMastery",LargeIconGrpBot,"elemental\\elemental_mastery",lgIcon);
InitializeFrames("FireElemental",LargeIconGrpBot,"elemental\\fire_elemental",lgIcon);
InitializeFrames("FlameShock",LargeIconGrpTop,"shared\\flame_shock",lgIcon,lgGlow);
InitializeFrames("Icefury",LargeIconGrpBot,"elemental\\icefury",lgIcon);
InitializeFrames("LavaBurst",LargeIconGrpTop,"elemental\\lava_burst",lgIcon,lgGlow,true);
InitializeFrames("LiquidMagmaTotem",LargeIconGrpBot,"totems\\liquid_magma_totem",lgIcon);
InitializeFrames("StormElemental",LargeIconGrpBot,"elemental\\storm_elemental",lgIcon);
InitializeFrames("Stormkeeper",LargeIconGrpBot,"elemental\\stormkeeper",lgIcon);

-- Build Small Elemental Icon Frames
InitializeFrames("AncestralGuidanceEle",SmallIconGrpLeft,"shared\\ancestral_guidance",smIcon);
InitializeFrames("AstralShiftEle",SmallIconGrpLeft,"shared\\astral_shift",smIcon);
InitializeFrames("CleanseSpiritEle",SmallIconGrpLeft,"restoration\\purify_spirit",smIcon);
InitializeFrames("EarthElemental",SmallIconGrpRight,"elemental\\earth_elemental",smIcon);
InitializeFrames("EarthgrabTotemEle",SmallIconGrpRight,"totems\\earthgrab_totem",smIcon);
InitializeFrames("GustWindEle",SmallIconGrpRight,"shared\\gust_of_wind",smIcon);
InitializeFrames("HexEle",SmallIconGrpLeft,"shared\\hex",smIcon);
InitializeFrames("LightningSurgeTotemEle",SmallIconGrpRight,"totems\\lightning_surge_totem",smIcon);
InitializeFrames("Thunderstorm",SmallIconGrpRight,"elemental\\thunderstorm",smIcon);
InitializeFrames("VoodooTotemEle",SmallIconGrpLeft,"totems\\voodoo_totem",smIcon);
InitializeFrames("WindRushTotemEle",SmallIconGrpRight,"totems\\wind_rush_totem",smIcon);
InitializeFrames("WindShearEle",SmallIconGrpLeft,"shared\\wind_shear",smIcon);

-------------------------------------------------------------------------------------------------------
----- Build and Initialize Status Bars
-------------------------------------------------------------------------------------------------------

-- Build Maelstrom Status Bar
SSA.MaelstromBarEle = CreateFrame("StatusBar","MaelstromBarEle",AuraGroup);
local MaelstromBar = SSA.MaelstromBarEle;

MaelstromBar:SetStatusBarTexture("Interface\\addons\\ShamanAuras\\media\\statusbar\\fifths");
MaelstromBar:GetStatusBarTexture():SetHorizTile(false);
MaelstromBar:GetStatusBarTexture():SetVertTile(false);
MaelstromBar:SetPoint("CENTER",AuraGroup,"CENTER",0,-139);
MaelstromBar:SetWidth(260);
MaelstromBar:SetHeight(21);
MaelstromBar:SetFrameStrata("LOW");
MaelstromBar:SetStatusBarColor(0,0.5,1);
--MaelstromBar:SetUserPlaced(true);
MaelstromBar:SetAlpha(0);

MaelstromBar.bg = MaelstromBar:CreateTexture(nil,"BACKGROUND");
MaelstromBar.bg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar");
MaelstromBar.bg:SetAllPoints(true);
MaelstromBar.bg:SetVertexColor(0,0,0);
MaelstromBar.bg:SetAlpha(0.5);

MaelstromBar.text = MaelstromBar:CreateFontString(nil, "HIGH", "GameFontHighlightLarge");
MaelstromBar.text:SetPoint("CENTER",MaelstromBar,"CENTER",0,0);
MaelstromBar.text:SetFont("Fonts\\FRIZQT__.TTF", 12);
MaelstromBar.text:SetTextColor(1,1,1,1);

--[[SSA.MaelstromBarEleLightning = CreateFrame("PlayerModel","MaelstromBarEleLightning",AuraGroup);
local MaelstromBarLightning = SSA.MaelstromBarEleLightning;
MaelstromBarLightning:SetModel("SPELLS/LIGHTNING_AREA_DISC_STATE.m2");
MaelstromBarLightning:SetFrameStrata("MEDIUM");
MaelstromBarLightning:SetPosition(0,0,-2);
MaelstromBarLightning:SetPoint("CENTER",AuraGroup,"CENTER",0,-139);
MaelstromBarLightning:SetWidth(260);
MaelstromBarLightning:SetHeight(21);
--MaelstromBarLightning:SetAllPoints(MaelstromBar);
MaelstromBarLightning:SetAlpha(0);
MaelstromBarLightning:Show();
local elapsed = 0;
MaelstromBarLightning:HookScript("OnUpdate", function(self, elaps)
	elapsed = elapsed + (elaps * 1000);
	self:SetSequenceTime(1, elapsed);
end);]]
MaelstromBar.Elapsed = 0;
MaelstromBar.Lightning = CreateFrame("PlayerModel","MaelstromBarEleLightning",MaelstromBar);
MaelstromBar.Lightning:SetModel("SPELLS/LIGHTNING_AREA_DISC_STATE.m2");
MaelstromBar.Lightning:SetFrameStrata("MEDIUM");
MaelstromBar.Lightning:SetPosition(0,0,-2);
MaelstromBar.Lightning:SetAllPoints(MaelstromBar);
--MaelstromBarLightning:SetAllPoints(MaelstromBar);
MaelstromBar.Lightning:SetAlpha(0);
--MaelstromBar.Lightning:Show();
MaelstromBar.Lightning:SetScript("OnUpdate", function(self, elaps)
	--SSA.ErrorFrame.text:SetText("Elapsed: "..tostring(MaelstromBar.Elapsed));
	MaelstromBar.Elapsed = MaelstromBar.Elapsed + (elaps * 1000);
	self:SetSequenceTime(1, MaelstromBar.Elapsed);
end);



-- Build Icefury Status Bar
SSA.IcefuryBar = CreateFrame("StatusBar","IcefuryBar",AuraGroup);
local IcefuryBar = SSA.IcefuryBar;
IcefuryBar:SetStatusBarTexture("Interface\\addons\\ShamanAuras\\media\\statusbar\\fourths");
IcefuryBar:GetStatusBarTexture():SetHorizTile(false);
IcefuryBar:GetStatusBarTexture():SetVertTile(false);
IcefuryBar:SetPoint("CENTER",AuraGroup,"CENTER",0,-110);
IcefuryBar:SetWidth(260);
IcefuryBar:SetHeight(21);
IcefuryBar:SetFrameStrata("LOW");
IcefuryBar:SetStatusBarColor(0.66,0.49,1);
IcefuryBar:Hide();

IcefuryBar.bg = IcefuryBar:CreateTexture(nil,"BACKGROUND");
IcefuryBar.bg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar");
IcefuryBar.bg:SetAllPoints(true);
IcefuryBar.bg:SetVertexColor(0,0,0);
IcefuryBar.bg:SetAlpha(0.9);

-- Build Icefury Timer Status Bar
IcefuryBar.Timer = CreateFrame("StatusBar","IcefuryTimer",IcefuryBar);
IcefuryBar.Timer:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar");
IcefuryBar.Timer:GetStatusBarTexture():SetHorizTile(false);
IcefuryBar.Timer:GetStatusBarTexture():SetVertTile(false);
IcefuryBar.Timer:SetWidth(IcefuryBar:GetWidth());
IcefuryBar.Timer:SetHeight(IcefuryBar:GetHeight());
IcefuryBar.Timer:SetFrameStrata("MEDIUM");
IcefuryBar.Timer:SetPoint("CENTER",IcefuryBar,"CENTER",0,0);
IcefuryBar.Timer:SetStatusBarColor(1,1,1,0.35);

IcefuryBar.Timer.text = IcefuryBar.Timer:CreateFontString(nil, "HIGH", "GameFontHighlightLarge");
IcefuryBar.Timer.text:SetPoint("CENTER",IcefuryBar.Timer,"LEFT",25,0);
IcefuryBar.Timer.text:SetFont("Interface\\addons\\ShamanAuras\\Media\\fonts\\Continuum_Medium.ttf", 12);
IcefuryBar.Timer.text:SetTextColor(1,1,1,1);

-- Build Buff Timer Status Bar Group
SSA.BuffTimerBarGrpEle = CreateFrame("Frame","BuffTimerBarGrpEle",AuraGroup);
local BuffTimerBarGrp = SSA.BuffTimerBarGrpEle;
BuffTimerBarGrp:SetWidth(115);
BuffTimerBarGrp:SetHeight(180);
BuffTimerBarGrp:SetBackdrop(nil);
BuffTimerBarGrp:Show();

-- Build Main Timer Status Bar Group
SSA.MainTimerBarGrpEle = CreateFrame("Frame","MainTimerBarGrpEle",AuraGroup);
local MainTimerBarGrp = SSA.MainTimerBarGrpEle;
MainTimerBarGrp:SetWidth(90);
MainTimerBarGrp:SetHeight(180);
MainTimerBarGrp:SetBackdrop(nil);
MainTimerBarGrp:Show();

-- Build Utility Timer Status Bar Group
SSA.UtilTimerBarGrpEle = CreateFrame("Frame","UtilTimerBarGrpEle",AuraGroup);
local UtilTimerBarGrp = SSA.UtilTimerBarGrpEle;
UtilTimerBarGrp:SetFrameStrata("LOW");
UtilTimerBarGrp:SetWidth(47);
UtilTimerBarGrp:SetHeight(180);
UtilTimerBarGrp:SetBackdrop(nil);
UtilTimerBarGrp:Show();

-- Build Elemental Vertical Status Bars	
SSA.AncestralGuidanceBarEle = CreateFrame("StatusBar","AncestralGuidanceBarEle",BuffTimerBarGrp);
SSA.AscendanceBarEle = CreateFrame("StatusBar","AscendanceBarEle",BuffTimerBarGrp);
SSA.AstralShiftBarEle = CreateFrame("StatusBar","AstralShiftBarEle",BuffTimerBarGrp);
SSA.BloodlustBarEle = CreateFrame("StatusBar","BloodlustBarEle",BuffTimerBarGrp);
SSA.EarthgrabTotemBarEle = CreateFrame("StatusBar","EarthgrabTotemBarEle",MainTimerBarGrp);
SSA.ElementalBlastCritBar = CreateFrame("StatusBar","ElementalBlastCritBar",BuffTimerBarGrp);
SSA.ElementalBlastHasteBar = CreateFrame("StatusBar","ElementalBlastHasteBar",BuffTimerBarGrp);
SSA.ElementalBlastMasteryBar = CreateFrame("StatusBar","ElementalBlastMasteryBar",BuffTimerBarGrp);
SSA.FireElementalBar = CreateFrame("StatusBar","FireElementalBar",UtilTimerBarGrp);
SSA.HexBarEle = CreateFrame("StatusBar","HexBarEle",MainTimerBarGrp);
SSA.LiquidMagmaTotemBar = CreateFrame("StatusBar","LiquidMagmaTotemBar",MainTimerBarGrp);
SSA.StormElementalBar = CreateFrame("StatusBar","StormElementalBar",UtilTimerBarGrp);
SSA.EarthElementalBar = CreateFrame("StatusBar","EarthElementalBar",UtilTimerBarGrp);
SSA.ElementalMasteryBar = CreateFrame("StatusBar","ElementalMasteryBar",BuffTimerBarGrp);
SSA.VoodooTotemBarEle = CreateFrame("StatusBar","VoodooTotemBarEle",MainTimerBarGrp);
SSA.WindRushTotemBarEle = CreateFrame("StatusBar","WindRushTotemBarEle",MainTimerBarGrp);

-- Totem Mastery Notification
SSA.TotemMastery = CreateFrame("Frame","TotemMastery",AuraGroup);
local TotemMastery = SSA.TotemMastery;
TotemMastery:SetPoint("CENTER",0,-210);
TotemMastery:SetWidth(400);
TotemMastery:SetHeight(180);
TotemMastery:SetFrameStrata("BACKGROUND");
TotemMastery:Hide();

TotemMastery.texture = TotemMastery:CreateTexture(nil,"LOW");
TotemMastery.texture:SetTexture("Textures\\SpellActivationOverlays\\Echo_of_the_Elements");
TotemMastery.texture:SetPoint("CENTER",TotemMastery,"CENTER",0,0);
TotemMastery.texture:SetWidth(TotemMastery:GetWidth() + 20);
TotemMastery.texture:SetHeight(TotemMastery:GetHeight());
TotemMastery.texture:SetRotation(math.rad(-90));
TotemMastery.texture:SetAlpha(0.7);

-- Animation for Totem Mastery Notification Texture
TotemMastery.Flash = TotemMastery.texture:CreateAnimationGroup();
TotemMastery.Flash:SetLooping("BOUNCE");

TotemMastery.Flash.fadeIn = TotemMastery.Flash:CreateAnimation("Alpha");
TotemMastery.Flash.fadeIn:SetFromAlpha(1);
TotemMastery.Flash.fadeIn:SetToAlpha(0.4);
TotemMastery.Flash.fadeIn:SetDuration(0.4);

TotemMastery.Flash.fadeOut = TotemMastery.Flash:CreateAnimation("Alpha");
TotemMastery.Flash.fadeOut:SetFromAlpha(0.4);
TotemMastery.Flash.fadeOut:SetToAlpha(1);
TotemMastery.Flash.fadeOut:SetDuration(0.4);
TotemMastery.Flash.fadeOut:SetEndDelay(0);

-- Lava Surge Progress Bar/Texture (LEFT)
SSA.LavaSurgeEle = CreateFrame("Frame","LavaSurgeEle",AuraGroup);
local LavaSurge = SSA.LavaSurgeEle;

--[[LavaSurge:SetStatusBarTexture("Textures\\SpellActivationOverlays\\Imp_Empowerment");
LavaSurge:GetStatusBarTexture():SetHorizTile(false);
LavaSurge:GetStatusBarTexture():SetVertTile(false);
LavaSurge:SetOrientation("VERTICAL");]]
--LavaSurge:SetRotatesTexture(true);
LavaSurge:SetPoint("CENTER",AuraGroup,"CENTER",-130,0);
LavaSurge:SetWidth(116);
LavaSurge:SetHeight(200);
LavaSurge:SetFrameStrata("BACKGROUND");
--LavaSurge:SetStatusBarColor(1,1,1);
LavaSurge:Hide();

LavaSurge.texture = LavaSurge:CreateTexture(nil,"LOW");
LavaSurge.texture:SetTexture("Textures\\SpellActivationOverlays\\Imp_Empowerment");
LavaSurge.texture:SetPoint("CENTER",LavaSurge,"CENTER",0,0);
LavaSurge.texture:SetWidth(LavaSurge:GetWidth() + 20);
LavaSurge.texture:SetHeight(LavaSurge:GetHeight());
--LavaSurge.texture:SetRotation(math.rad(-90));
LavaSurge.texture:SetAlpha(1);

--[[LavaSurge.bg = LavaSurge:CreateTexture(nil,"BACKGROUND");
LavaSurge.bg:SetTexture("Textures\\SpellActivationOverlays\\Imp_Empowerment");
LavaSurge.bg:SetAllPoints(true);
LavaSurge.bg:SetVertexColor(1,1,1);
LavaSurge.bg:SetAlpha(0.5);]]

LavaSurge.Scaler = LavaSurge:CreateAnimationGroup();
LavaSurge.Scaler:SetLooping("REPEAT");

local scalePush = 1.08;
local scalePull = 1 / scalePush;

LavaSurge.Scaler.scaleOut = LavaSurge.Scaler:CreateAnimation("Scale")
LavaSurge.Scaler.scaleOut:SetOrder(1)
LavaSurge.Scaler.scaleOut:SetDuration(0.5)
LavaSurge.Scaler.scaleOut:SetSmoothing("IN_OUT")
LavaSurge.Scaler.scaleOut:SetFromScale(1,1)
LavaSurge.Scaler.scaleOut:SetToScale(1,scalePush)
 
LavaSurge.Scaler.scaleIn = LavaSurge.Scaler:CreateAnimation("Scale")
LavaSurge.Scaler.scaleIn:SetOrder(2)
LavaSurge.Scaler.scaleIn:SetDuration(0.5)
LavaSurge.Scaler.scaleIn:SetSmoothing("IN_OUT")
LavaSurge.Scaler.scaleIn:SetFromScale(1,1)
LavaSurge.Scaler.scaleIn:SetToScale(1,scalePull)

-- Stormkeeper Charges
SSA.StormkeeperChargeGrp = CreateFrame("Frame","StormkeeperChargeGrp",AuraGroup);
local StormkeeperCharges = SSA.StormkeeperChargeGrp;
StormkeeperCharges:SetFrameStrata(bg);
StormkeeperCharges:SetWidth(260);
StormkeeperCharges:SetHeight(50);
StormkeeperCharges:SetPoint("CENTER",AuraGroup,"CENTER",0,-110);
StormkeeperCharges:Show();

--SSA.ErrorFrame.text:SetText("Name: "..StormkeeperCharges:GetName())
StormkeeperCharges.Charge1 = CreateFrame("Frame","StormkeeperCharge1",StormkeeperCharges);
--local StormkeeperCharge1 = SSA.StormkeeperCharge1;
StormkeeperCharges.Charge1:SetWidth(100);
StormkeeperCharges.Charge1:SetHeight(100);
StormkeeperCharges.Charge1:SetPoint("CENTER",StormkeeperCharges,"LEFT",30,-3);
StormkeeperCharges.Charge1:Hide();

StormkeeperCharges.Charge1.Lightning = CreateFrame("PlayerModel","StormkeeperCharge1_Lightning",StormkeeperCharges.Charge1);
StormkeeperCharges.Charge1.Lightning:SetModel("spells/Monk_chiblast_precast.m2");
StormkeeperCharges.Charge1.Lightning:SetFrameStrata(low);
StormkeeperCharges.Charge1.Lightning:SetPosition(0,0,0);
StormkeeperCharges.Charge1.Lightning:SetAllPoints(StormkeeperCharges.Charge1);
StormkeeperCharges.Charge1.Lightning:SetAlpha(1);
StormkeeperCharges.Charge1.Lightning:HookScript("OnUpdate", function(self, elaps)
	elapsed = elapsed + (elaps * 1000);
	self:SetSequenceTime(1, elapsed);
end);

StormkeeperCharges.Charge2 = CreateFrame("Frame","StormkeeperCharge2",StormkeeperCharges);
--local StormkeeperCharges.Charge2 = SSA.StormkeeperCharges.Charge2;
StormkeeperCharges.Charge2:SetWidth(100);
StormkeeperCharges.Charge2:SetHeight(100);
StormkeeperCharges.Charge2:SetPoint("CENTER",StormkeeperCharges,"CENTER",0,-3);
StormkeeperCharges.Charge2:Hide();

StormkeeperCharges.Charge2.Lightning = CreateFrame("PlayerModel","StormkeeperCharge2_Lightning",StormkeeperCharges.Charge2);
StormkeeperCharges.Charge2.Lightning:SetModel("spells/Monk_chiblast_precast.m2");
StormkeeperCharges.Charge2.Lightning:SetFrameStrata(low);
StormkeeperCharges.Charge2.Lightning:SetPosition(0,0,0);
StormkeeperCharges.Charge2.Lightning:SetAllPoints(StormkeeperCharges.Charge2);
StormkeeperCharges.Charge2.Lightning:SetAlpha(1);
StormkeeperCharges.Charge2.Lightning:HookScript("OnUpdate", function(self, elaps)
	elapsed = elapsed + (elaps * 1000);
	self:SetSequenceTime(1, elapsed);
end);

StormkeeperCharges.Charge3 = CreateFrame("Frame","StormkeeperCharge3",StormkeeperCharges);
--local StormkeeperCharges.Charge3 = SSA.StormkeeperCharges.Charge3;
StormkeeperCharges.Charge3:SetWidth(100);
StormkeeperCharges.Charge3:SetHeight(100);
StormkeeperCharges.Charge3:SetPoint("CENTER",StormkeeperCharges,"RIGHT",-30,-3);
StormkeeperCharges.Charge3:Hide();

StormkeeperCharges.Charge3.Lightning = CreateFrame("PlayerModel","StormkeeperCharge3_Lightning",StormkeeperCharges.Charge3);
StormkeeperCharges.Charge3.Lightning:SetModel("spells/Monk_chiblast_precast.m2");
StormkeeperCharges.Charge3.Lightning:SetFrameStrata(low);
StormkeeperCharges.Charge3.Lightning:SetPosition(0,0,0);
StormkeeperCharges.Charge3.Lightning:SetAllPoints(StormkeeperCharges.Charge3);
StormkeeperCharges.Charge3.Lightning:SetAlpha(1);
StormkeeperCharges.Charge3.Lightning:HookScript("OnUpdate", function(self, elaps)
	elapsed = elapsed + (elaps * 1000);
	self:SetSequenceTime(1, elapsed);
end);

-------------------------------------------------------------------------------------------------------
----- Build Move UI
-------------------------------------------------------------------------------------------------------

-- Initialize Check Button Frames
SSA.MoveEle = CreateFrame("Frame","MoveEle",UIParent);

SSA.AuraObjectsEle = {
	[1] = AuraGroup,
	[2] = LargeIconGrpTop,
	[3] = LargeIconGrpBot,
	[4] = SmallIconGrpLeft,
	[5] = SmallIconGrpRight,
	[6] = BuffTimerBarGrp,
	[7] = MainTimerBarGrp,
	[8] = UtilTimerBarGrp,
	[9] = MaelstromBar,
	[10] = IcefuryBar,
	[11] = TotemMastery,
	[12] = LavaSurge,
	[13] = StormkeeperChargeGrp,
}

SSA.MoveStringsEle = {
	[1] = L["Move All Auras"],
	[2] = L["Move Top Auras"],
	[3] = L["Move Bottom Auras"],
	[4] = L["Move Left Auras"],
	[5] = L["Move Right Auras"],
	[6] = L["Move Buff Timer Bars"],
	[7] = L["Move Main Timer Bars"],
	[8] = L["Move Utility Timer Bars"],
	[9] = L["Move Maelstrom Bar"],
	[10] = L["Move Icefury Bar"],
	[11] = L["Move Totem Mastery Alert"],
	[12] = L["Move Lava Surge Texture"],
	[13] = L["Move Stormkeeper Charges"],
}